import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'dataLink',
    label: '',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '请选择数据链接',
      options: [
        { label: '17kundb', value: '17kundb' },
        { label: 'postgres', value: 'postgres' },
        { label: '18inceptor', value: '18inceptor' },
      ],
    },
  },
  {
    field: 'databaseLink',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '请选择数据库链接',
      options: [
        { label: 'DEMO', value: 'DEMO' },
        { label: 'test_zhongjiao', value: 'test_zhongjiao' },
      ],
    },
  },
  {
    field: 'dataTable',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '请选择数据表链接',
      options: [
        { label: 'fs_assets', value: 'fs_assets' },
        { label: 'company_base', value: 'company_base' },
      ],
    },
  },
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '字段名',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感状态',
      options: [
        { label: '敏感', value: '敏感' },
        { label: '不敏感', value: '不敏感' },
      ],
    },
  },
  {
    field: 'level',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '安全分级',
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
      ],
    },
  },
  {
    field: 'sensitiveType',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: 'dy类型1', value: 'dy类型1' },
        { label: 'dy类型2', value: 'dy类型2' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '数据链接',
    dataIndex: 'dataLink',
    width: 120,
  },
  {
    title: '数据目录',
    dataIndex: 'dataContents',
    width: 120,
  },
  {
    title: '数据库',
    dataIndex: 'databaseLink',
    width: 120,
  },
  {
    title: '数据表',
    dataIndex: 'dataTable',
    width: 140,
  },
  {
    title: '字段名',
    dataIndex: 'name',
    width: 140,
  },
  {
    title: '敏感状态',
    dataIndex: 'flag',
    width: 180,
  },
  {
    title: '安全分级',
    dataIndex: 'level',
    width: 180,
  },
  {
    title: '敏感类型',
    dataIndex: 'sensitiveType',
    width: 180,
  },
];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'flag',
    label: '敏感状态',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感状态',
      options: [
        { label: '敏感', value: '敏感' },
        { label: '不敏感', value: '不敏感' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择敏感状态',
      },
    ],
  },
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: 'dy类型1', value: 'dy类型1' },
        { label: 'dy类型2', value: 'dy类型2' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
    dynamicRules: ({ values }) => {
      return values.flag === '敏感' ? [{ required: true, message: '说明必填' }] : [];
    },
  },

  {
    field: 'level',
    label: '安全分级',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '安全分级',
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
        { label: 'G4', value: 'G4' },
        { label: 'G5', value: 'G5' },
      ],
    },
    dynamicRules: ({ values }) => {
      return values.flag === '敏感' ? [{ required: true, message: '说明必填' }] : [];
    },
  },
]
