import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '搜索对象',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '对象属性',
      options: [
        { label: '系统管理员', value: '系统管理员' },
        { label: '一般人员', value: '一般人员' },
      ],
    },
  },
  {
    field: 'level',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '安全分级',
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
        { label: 'G4', value: 'G4' },
      ],
    },
  },
  {
    field: 'type',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '血缘关系', value: '血缘关系' },
        { label: '钱包类型', value: '钱包类型' },
        { label: '员工号（对外员工）', value: '员工号（对外员工）' },
      ],
    },
  },
  {
    field: 'protectiveAction',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: '放行', value: '放行' },
        { label: '脱敏', value: '脱敏' },
        { label: '拒绝', value: '拒绝' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '对象',
    dataIndex: 'object',
    width: 120,
  },
  {
    title: '敏感类型',
    dataIndex: 'sensitiveType',
    width: 120,
  },
  {
    title: '安全分级',
    dataIndex: 'safetyLevel',
    width: 120,
  },
  {
    title: '优先级',
    dataIndex: 'priority',
    width: 140,
  },
  {
    title: '保护动作',
    dataIndex: 'protectiveAction',
    width: 140,
  },
];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '血缘关系', value: '血缘关系' },
        { label: '钱包类型', value: '钱包类型' },
        { label: '员工号（对外员工）', value: '员工号（对外员工）' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择敏感类型',
      },
    ],
  },
  {
    field: 'safetyLevel',
    label: '安全分级',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '安全分级',
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
        { label: 'G4', value: 'G4' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择安全分级',
      },
    ],
  },
  {
    field: 'priority',
    label: '优先级',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '优先级',
      options: [
        { label: '低', value: '低' },
        { label: '中', value: '中' },
        { label: '高', value: '高' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择保护动作',
      },
    ],
  },
  {
    field: 'protectiveAction',
    label: '保护动作',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: '放行', value: '放行' },
        { label: '脱敏', value: '脱敏' },
        { label: '拒绝', value: '拒绝' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择保护动作',
      },
    ],
  },
  {
    field: 'protectiveActionFun',
    label: '脱敏算法',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '脱敏算法',
      options: [
        { label: 'Unbase64', value: 'Unbase64' },
      ],
    },
    ifShow: ({ values }) => values.protectiveAction === '脱敏',
    rules: [
      {
        required: true,
        message: '请选择脱敏算法',
      },
    ],
  },
  {
    field: 'name',
    label: '算法参数',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '算法参数',
    },
    ifShow: ({ values }) => values.protectiveAction === '脱敏',
  },
]
